/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef KFTPLOGVIEW_H
#define KFTPLOGVIEW_H

#include <KAction>

#include <QAbstractScrollArea>
#include <QTextStream>
#include <QTextLayout>
#include <QMenu>
#include <QList>

namespace KFTPWidgets {

/**
 * This class provides a simple fast log widget.
 *
 * @author Jernej Kos
 */
class LogView : public QAbstractScrollArea
{
Q_OBJECT
public:
    /**
     * Valid line format types.
     */
    enum LineType {
      FtpResponse = 0,
      FtpCommand,
      FtpMultiline,
      FtpStatus,
      FtpError,
      Plain
    };
    
    /**
     * Class constructor.
     *
     * @param parent Parent widget
     */
    LogView(QWidget *parent);
    
    /**
     * Class destructor.
     */
    ~LogView();

    /**
     * Appends some text.
     *
     * @param str String to append
     * @param type Optional line format type
     */
    void append(const QString &str, LineType type = Plain);
protected:
    KAction *m_saveToFileAction;
    KAction *m_clearLogAction;
    
    /**
     * @overload
     * Reimplemented from QAbstractScrollArea.
     */
    void contextMenuEvent(QContextMenuEvent *event);
    
    /**
     * @overload
     * Reimplemented from QAbstractScrollArea.
     */
    void paintEvent(QPaintEvent *event);
    
    /**
     * @overload
     * Reimplemented from QAbstractScrollArea.
     */
    void resizeEvent(QResizeEvent *event);
    
    /**
     * @overload
     * Reimplemented from QAbstractScrollArea.
     */
    void keyPressEvent(QKeyEvent *e);
    
    /**
     * Paints the text.
     */
    void paint(QPainter *p, QPaintEvent *e);
    
    /**
     * A helper method for updating scrollbar ranges.
     */
    void updateScrollbar();
    
    /**
     * A helper method for managing maximum line limits.
     */
    void manageLimit();
private:
    /**
     * A simple line representation.
     */
    class Line {
    public:
        QString prefix;
        QString text;
        int width;
        LineType type;
        QList<QTextLayout::FormatRange> formatRanges;
    };
    
    QList<Line> m_content;
    QFont m_curFont;
    int m_fontsize;
    int m_numberOfLines;
    int m_maxLineWidth;
    int m_limit;
public slots:
    /**
     * Clears the current text.
     */
    void clear();
private slots:
    void slotSaveToFile();
};

}

#endif
